# Merged model

This folder contains the fully resolved pid4cat model, including all imported models.
The files are auto-generated from the schema in the `src/pid4cat_model/schema` folder and version-stamped by uv-dynamic-versioning.
For releases, these files are copied to gh-pages along with the rest of the documentation, making schema files with version information available on gh-pages.
The w3id.org redirects link to these files.

Note, that the generated files are git-ignored.
